REST PKI client lib for Python
===============================
This library contains classes that encapsulate the calls to the REST PKI API.

The recommend way to install **Rest PKI Client Lib** is through [PyPi](https://pypi.org/):

    $ pip install restpki-client

Or informing on your project's `requirements.txt` file:

    restpki-client==1.1.0

Samples
-------

Please visit the [REST PKI samples repository](https://github.com/LacunaSoftware/RestPkiSamples/tree/master/Python)
for examples on how to use this library.